==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN مفعل</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN مغلق</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>فتح 键锁定</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>غلق 键锁定</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>فتح لوحة الأرقام</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>غلق لوحة الأرقام</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>فتح لوحة اللمس</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>غلق لوحة اللمس</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>GGLE لوحة اللمس</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>GGLE لوحة التحكم</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>فتح وضع الطائرة</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>غلق وضع الطائرة</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>طاقة متوازنة</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>توفير الطاقة</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>أداء عالٍ</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>تم تفعيل تأثيرات النافذة</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>تم تعطيل تأثيرات النافذة</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>فشل في تفعيل تأثيرات النافذة</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_az.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="az">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN مفعل</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN مغلق</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>فتح 键锁定</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>غلق 键锁定</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>فتح لوحة الأرقام</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>غلق لوحة الأرقام</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>فتح لوحة اللمس</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>غلق لوحة اللمس</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>GGLE لوحة اللمس</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>GGLE لوحة التحكم</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>فتح وضع الطائرة</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>غلق وضع الطائرة</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>طاقة متوازنة</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>توفير الطاقة</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>أداء عالٍ</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>تم تفعيل تأثيرات النافذة</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>تم تعطيل تأثيرات النافذة</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>فشل في تفعيل تأثيرات النافذة</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera off</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
